@@ -9,7 +9,7 @@ var searchData=
   ['2_20–_202025_2010_2020_6',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2&quot;&gt;1.12.2&lt;/a&gt; – 2025-10-20',['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'']]],
   ['2_200_20–_202021_2004_2003_7',['libxkbcommon 1.2.0 – 2021-04-03',['../release-notes.html#libxkbcommon-120--2021-04-03',1,'']]],
   ['2_201_20–_202021_2004_2007_8',['libxkbcommon 1.2.1 – 2021-04-07',['../release-notes.html#libxkbcommon-121--2021-04-07',1,'']]],
-  ['20_9',['20',['../release-notes.html#libxkbcommon-102--2020-11-20',1,'libxkbcommon 1.0.2 – 2020-11-20'],['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'libxkbcommon <a href="https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2">1.12.2</a> – 2025-10-20']]],
+  ['20_9',['20',['../release-notes.html#libxkbcommon-102--2020-11-20',1,'libxkbcommon 1.0.2 – 2020-11-20'],['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2&quot;&gt;1.12.2&lt;/a&gt; – 2025-10-20']]],
   ['2013_2004_2001_10',['libxkbcommon 0.3.0 – 2013-04-01',['../release-notes.html#libxkbcommon-030--2013-04-01',1,'']]],
   ['2013_2006_2003_11',['libxkbcommon 0.3.1 – 2013-06-03',['../release-notes.html#libxkbcommon-031--2013-06-03',1,'']]],
   ['2013_2011_2022_12',['libxkbcommon 0.3.2 – 2013-11-22',['../release-notes.html#libxkbcommon-032--2013-11-22',1,'']]],
@@ -55,18 +55,20 @@ var searchData=
   ['2025_2010_2017_52',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.1&quot;&gt;1.12.1&lt;/a&gt; – 2025-10-17',['../release-notes.html#libxkbcommon-1121--2025-10-17',1,'']]],
   ['2025_2010_2020_53',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2&quot;&gt;1.12.2&lt;/a&gt; – 2025-10-20',['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'']]],
   ['2025_2010_2029_54',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.3&quot;&gt;1.12.3&lt;/a&gt; – 2025-10-29',['../release-notes.html#libxkbcommon-1123--2025-10-29',1,'']]],
-  ['203_20–_20invalid_20include_20statement_55',['XKB-203 – Invalid include statement',['../error-index.html#XKB-203',1,'']]],
-  ['206_20–_20invalid_20modmap_20entry_56',['XKB-206 – Invalid modmap entry',['../error-index.html#XKB-206',1,'']]],
-  ['21_57',['21',['../release-notes.html#libxkbcommon-141--2022-05-21',1,'libxkbcommon 1.4.1 – 2022-05-21'],['../release-notes.html#libxkbcommon-1100--2025-05-21',1,'libxkbcommon <a href="https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.10.0">1.10.0</a> – 2025-05-21']]],
-  ['22_58',['22',['../release-notes.html#libxkbcommon-032--2013-11-22',1,'libxkbcommon 0.3.2 – 2013-11-22'],['../release-notes.html#libxkbcommon-084--2019-02-22',1,'libxkbcommon 0.8.4 – 2019-02-22']]],
-  ['23_59',['libxkbcommon 1.0.3 – 2020-11-23',['../release-notes.html#libxkbcommon-103--2020-11-23',1,'']]],
-  ['237_20–_20unsupported_20group_20index_60',['XKB-237 – Unsupported group index',['../error-index.html#XKB-237',1,'']]],
-  ['239_20–_20conflicting_20key_20type_20level_20names_61',['XKB-239 – Conflicting key type level names',['../error-index.html#XKB-239',1,'']]],
-  ['24_62',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.7.0&quot;&gt;1.7.0&lt;/a&gt; – 2024-03-24',['../release-notes.html#libxkbcommon-170--2024-03-24',1,'']]],
-  ['254_20–_20invalid_20set_20default_20statement_63',['XKB-254 – Invalid set default statement',['../error-index.html#XKB-254',1,'']]],
-  ['26_64',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.0&quot;&gt;1.9.0&lt;/a&gt; – 2025-04-26',['../release-notes.html#libxkbcommon-190--2025-04-26',1,'']]],
-  ['266_20–_20conflicting_20key_20type_20map_20entry_65',['XKB-266 – Conflicting key type map entry',['../error-index.html#XKB-266',1,'']]],
-  ['27_66',['27',['../release-notes.html#libxkbcommon-041--2014-03-27',1,'libxkbcommon 0.4.1 – 2014-03-27'],['../release-notes.html#libxkbcommon-110--2021-02-27',1,'libxkbcommon 1.1.0 – 2021-02-27']]],
-  ['286_20–_20undefined_20key_20type_67',['XKB-286 – Undefined key type',['../error-index.html#XKB-286',1,'']]],
-  ['29_68',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.3&quot;&gt;1.12.3&lt;/a&gt; – 2025-10-29',['../release-notes.html#libxkbcommon-1123--2025-10-29',1,'']]]
+  ['2025_2011_2005_55',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.13.0&quot;&gt;1.13.0&lt;/a&gt; – 2025-11-05',['../release-notes.html#libxkbcommon-1130--2025-11-05',1,'']]],
+  ['2025_2012_2003_56',['2025 12 03',['../release-notes.html#libxkbcommon-1124--2025-12-03',1,'libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.4&quot;&gt;1.12.4&lt;/a&gt; – 2025-12-03'],['../release-notes.html#libxkbcommon-1131--2025-12-03',1,'libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.13.1&quot;&gt;1.13.1&lt;/a&gt; – 2025-12-03']]],
+  ['203_20–_20invalid_20include_20statement_57',['XKB-203 – Invalid include statement',['../error-index.html#XKB-203',1,'']]],
+  ['206_20–_20invalid_20modmap_20entry_58',['XKB-206 – Invalid modmap entry',['../error-index.html#XKB-206',1,'']]],
+  ['21_59',['21',['../release-notes.html#libxkbcommon-141--2022-05-21',1,'libxkbcommon 1.4.1 – 2022-05-21'],['../release-notes.html#libxkbcommon-1100--2025-05-21',1,'libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.10.0&quot;&gt;1.10.0&lt;/a&gt; – 2025-05-21']]],
+  ['22_60',['22',['../release-notes.html#libxkbcommon-032--2013-11-22',1,'libxkbcommon 0.3.2 – 2013-11-22'],['../release-notes.html#libxkbcommon-084--2019-02-22',1,'libxkbcommon 0.8.4 – 2019-02-22']]],
+  ['23_61',['libxkbcommon 1.0.3 – 2020-11-23',['../release-notes.html#libxkbcommon-103--2020-11-23',1,'']]],
+  ['237_20–_20unsupported_20group_20index_62',['XKB-237 – Unsupported group index',['../error-index.html#XKB-237',1,'']]],
+  ['239_20–_20conflicting_20key_20type_20level_20names_63',['XKB-239 – Conflicting key type level names',['../error-index.html#XKB-239',1,'']]],
+  ['24_64',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.7.0&quot;&gt;1.7.0&lt;/a&gt; – 2024-03-24',['../release-notes.html#libxkbcommon-170--2024-03-24',1,'']]],
+  ['254_20–_20invalid_20set_20default_20statement_65',['XKB-254 – Invalid set default statement',['../error-index.html#XKB-254',1,'']]],
+  ['26_66',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.0&quot;&gt;1.9.0&lt;/a&gt; – 2025-04-26',['../release-notes.html#libxkbcommon-190--2025-04-26',1,'']]],
+  ['266_20–_20conflicting_20key_20type_20map_20entry_67',['XKB-266 – Conflicting key type map entry',['../error-index.html#XKB-266',1,'']]],
+  ['27_68',['27',['../release-notes.html#libxkbcommon-041--2014-03-27',1,'libxkbcommon 0.4.1 – 2014-03-27'],['../release-notes.html#libxkbcommon-110--2021-02-27',1,'libxkbcommon 1.1.0 – 2021-02-27']]],
+  ['286_20–_20undefined_20key_20type_69',['XKB-286 – Undefined key type',['../error-index.html#XKB-286',1,'']]],
+  ['29_70',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.3&quot;&gt;1.12.3&lt;/a&gt; – 2025-10-29',['../release-notes.html#libxkbcommon-1123--2025-10-29',1,'']]]
 ];
