@@ -6,7 +6,7 @@ var searchData=
   ['canonical_20and_20non_20canonical_20modifiers_3',['Canonical and non-canonical modifiers',['../keymap-text-format-v1-v2.html#canonical-and-non-canonical-modifiers',1,'']]],
   ['canonical_20modifiers_4',['Canonical and non-canonical modifiers',['../keymap-text-format-v1-v2.html#canonical-and-non-canonical-modifiers',1,'']]],
   ['cards_5',['Wild cards',['../rule-file-format.html#rules-wildcard-def',1,'']]],
-  ['changes_6',['changes',['../release-notes.html#breaking-changes',1,'Breaking changes'],['../release-notes.html#breaking-changes-1',1,'Breaking changes'],['../release-notes.html#breaking-changes-2',1,'Breaking changes'],['../release-notes.html#breaking-changes-3',1,'Breaking changes'],['../release-notes.html#breaking-changes-4',1,'Breaking changes'],['../release-notes.html#breaking-changes-5',1,'Breaking changes'],['../release-notes.html#breaking-changes-6',1,'Breaking changes'],['../release-notes.html#breaking-changes-7',1,'Breaking changes'],['../release-notes.html#breaking-changes-8',1,'Breaking changes'],['../release-notes.html#breaking-changes-9',1,'Breaking changes'],['../release-notes.html#breaking-changes-10',1,'Breaking changes']]],
+  ['changes_6',['changes',['../release-notes.html#breaking-changes',1,'Breaking changes'],['../release-notes.html#breaking-changes-1',1,'Breaking changes'],['../release-notes.html#breaking-changes-2',1,'Breaking changes'],['../release-notes.html#breaking-changes-3',1,'Breaking changes'],['../release-notes.html#breaking-changes-4',1,'Breaking changes'],['../release-notes.html#breaking-changes-5',1,'Breaking changes'],['../release-notes.html#breaking-changes-6',1,'Breaking changes'],['../release-notes.html#breaking-changes-7',1,'Breaking changes'],['../release-notes.html#breaking-changes-8',1,'Breaking changes'],['../release-notes.html#breaking-changes-9',1,'Breaking changes'],['../release-notes.html#breaking-changes-10',1,'Breaking changes'],['../release-notes.html#breaking-changes-11',1,'Breaking changes']]],
   ['char_20escape_20sequence_7',['XKB-645 – Unknown char escape sequence',['../error-index.html#XKB-645',1,'']]],
   ['client_20state_8',['Server State and Client State',['../group__state.html',1,'']]],
   ['code_9',['Code',['../md_doc_2quick-guide.html#code',1,'']]],
