@@ -1,6 +1,6 @@
 var indexSectionsWithContent =
 {
-  0: "0123456789abcdefghiklmnopqrstuvwx–“…",
+  0: "0123456789abcdefghiklmnopqrstuvwx–“…≤≥",
   1: "rx",
   2: "x",
   3: "rx",
@@ -9,8 +9,8 @@ var indexSectionsWithContent =
   6: "rx",
   7: "rx",
   8: "x",
-  9: "acdfhiklpqrsx",
-  10: "abcdefgiklmoqrstuvx"
+  9: "acdfhiklmnpqrsvx",
+  10: "0123456789abcdefghiklmnopqrstuvwx–“…≤≥"
 };
 
 var indexSectionNames =
